#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.16 2014/02/10 10:34:29 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "CommandLineParser.h"
#include "Config.h"
#include "Counter.h"
#include "IconEngine.h"
#include "ImageRecord.h"

class ImageRecordList;
class MainWindow;

/*!
\class  Application
\brief  Main Window singleton object
*/

class Application: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    Application( CommandLineArguments );

    //! destructor
    ~Application( void );

    //! application manager
    virtual bool initApplicationManager( void );

    //! create all widgets
    virtual bool realizeWidget( void );

    //! file list
    ImageRecordList& recentImages( void ) const
    { return *recentImages_; }

    //! retrieve MainWindow singleton
    MainWindow& mainWindow( void ) const
    { return *mainWindow_; }

    //!@name actions
    //@{

    //! open
    QAction& openAction( void ) const
    { return *openAction_; }

    //! reload
    QAction& reloadAction( void ) const
    { return *reloadAction_; }

    //! save
    QAction& saveAction( void ) const
    { return *saveAction_; }

    //! import
    QAction& importAction( void ) const
    { return *importAction_; }

    //! export
    QAction& exportAction( void ) const
    { return *exportAction_; }

    //@}

    //!@name application information
    //@{

    //! command line help
    void usage( void ) const;

    //! application name
    virtual QString applicationName( void ) const
    { return "Graphscan"; }

    //! application icon
    virtual QIcon applicationIcon( void ) const
    { return IconEngine::get( ":/graphscan.png" ); }

    // application version
    virtual QString applicationVersion( void ) const
    { return VERSION; }

    // build time stamp
    virtual QString buildTimeStamp( void ) const
    { return BUILD_TIMESTAMP; }

    //@}

    public Q_SLOTS:

    //! open
    void open( ImageRecord );

    protected Q_SLOTS:

    //! configuration
    virtual void _configuration( void );

    //! open
    void _open( void );

    //! save
    void _save( void );

    //! reload
    void _reload( void );

    //! exit safely
    void _exit( void );

    //! open data
    void _import( void );

    //! export data
    void _export( void );

    //! process request from application manager
    virtual bool _processCommand( Server::ServerCommand );

    //! about to quit
    virtual void _aboutToQuit( void );

    protected:

    //! install actions
    void _installActions( void );

    private:

    //! recent files
    ImageRecordList* recentImages_;

    //! main window entry selection frame
    MainWindow* mainWindow_;

    //!@name actions
    //@{

    //! open
    QAction* openAction_;

    //! save
    QAction* saveAction_;

    //! reload
    QAction* reloadAction_;

    //! import action
    QAction* importAction_;

    //! export action
    QAction* exportAction_;

    //@}

};

#endif
