#ifndef DataSetWidget_h
#define DataSetWidget_h

// $Id: DataSetWidget.h,v 1.5 2014/08/19 18:58:01 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "RefPoint.h"

#include <QAction>
#include <QComboBox>
#include <QWidget>

class DataSetWidget: public QWidget, public Counter
{

    Q_OBJECT

    public:

    //! constructor
    DataSetWidget( QWidget* = 0L );

    //! destructor
    virtual ~DataSetWidget( void )
    {}

    //! set collection
    void setCollection( const RefPoint::Collection& );

    //! select
    void select( int index )
    { combobox_->setCurrentIndex( index ); }

    Q_SIGNALS:

    //! add data set
    void dataSetAdded( void );

    //! remove data set
    void dataSetRemoved( void );

    //! select data set
    void dataSetSelected( int );

    protected Q_SLOTS:

    //! index changed
    void _indexChanged( int index )
    { if( !locked_ ) emit dataSetSelected( index ); }

    private:

    //! selection combobox
    QComboBox* combobox_;

    //! add data set button
    QAction* addAction_;

    //! remove data set button
    QAction* removeAction_;

    //! lock
    bool locked_;

};

#endif
