/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ImportImageDialog.h"
#include "ImportImageDialog.moc"

#include <QButtonGroup>
#include <QLabel>

//________________________________________________
ImportImageDialog::ImportImageDialog( QWidget* parent, const File& file, Modes mask ):
    CustomDialog( parent, OkButton|CancelButton|Separator )
{
    Debug::Throw( "ImportImageDialog::ImportImageDialog.\n" );
    setOptionName( "DUPLICATE_DIALOG" );

    const QString buffer = QString(
        tr( "Importing data for file '%1'. "
        "What do you want to do ?" ) ).arg( file.localName() );

    QLabel* label = new QLabel( buffer, this );
    label->setWordWrap( true );
    mainLayout().addWidget( label );
    mainLayout().addWidget( replaceCurrentCheckBox_ = new QRadioButton( tr( "Replace current data set" ), this ) );
    mainLayout().addWidget( replaceExistingCheckBox_ = new QRadioButton( tr( "Replace existing data set" ), this ) );
    mainLayout().addWidget( createCheckBox_ = new QRadioButton( tr( "Import as a new data set" ), this ) );

    // apply mask
    replaceCurrentCheckBox_->setVisible( mask & ReplaceCurrent );
    replaceExistingCheckBox_->setVisible( mask & ReplaceExisting );
    createCheckBox_->setVisible( mask & Create );

    QButtonGroup* group = new QButtonGroup( this );
    group->setExclusive( true );
    group->addButton( replaceCurrentCheckBox_ );
    group->addButton( replaceExistingCheckBox_ );
    group->addButton( createCheckBox_ );

}
