#ifndef RefPointErrorDialog_h
#define RefPointErrorDialog_h

// $Id: RefPointErrorDialog.h,v 1.8 2013/10/25 09:39:36 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"
#include "RefPoint.h"
#include "LineEditor.h"

#include <QCheckBox>
#include <QComboBox>
#include <QLabel>


class ErrorWidget: public QObject, public Counter
{

    Q_OBJECT

    public:

    //! constructor
    ErrorWidget( QWidget* );

    //! destructor
    virtual ~ErrorWidget( void )
    {}

    //! combobox
    QComboBox& comboBox( void )
    { return *combobox_; }

    //! plus editor
    LineEditor& plusEditor( void )
    { return *plusEditor_; }

    //! minus editor
    LineEditor& minusEditor( void )
    { return *minusEditor_; }

    //! relative checkbox
    QCheckBox& relativeCheckBox( void )
    { return *relativeCheckBox_; }

    //! return error
    void setError( const RefPoint::Error& error )
    {
        combobox_->setCurrentIndex( error.mode_ );
        plusEditor_->setText( QString::number( error.plus_ ) );
        minusEditor_->setText( QString::number( error.minus_ ) );
        relativeCheckBox_->setChecked( error.relative_ );
    }

    //! save
    void save( RefPoint::Error& ) const;

    //! enable state
    void setEnabled( bool value )
    {
        combobox_->setEnabled( value );
        plusEditor_->setEnabled( value );
        minusEditor_->setEnabled( value );
        relativeCheckBox_->setEnabled( value );
    }

    public Q_SLOTS:

    //! mode changed
    void _errorModeChanged( int );

    private:

    //! combobox
    QComboBox* combobox_;

    //! first editor
    LineEditor* plusEditor_;

    //! second editor
    LineEditor* minusEditor_;

    //! relative checkbox
    QCheckBox* relativeCheckBox_;

};

class RefPointErrorDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //! constructor
    RefPointErrorDialog( QWidget* );

    //! destructor
    virtual ~RefPointErrorDialog( void )
    {}

    //! set local point
    void setPoint( const RefPoint& );

    //! local point
    RefPoint point( void ) const;

    private:

    RefPoint point_;

    //! global label
    QLabel* globalLabel_;

    //! local label
    QLabel* localLabel_;

    //! error widget
    ErrorWidget* xErrorWidget_;

    //! error widget
    ErrorWidget* yErrorWidget_;

    //! error widget
    ErrorWidget* xErrorSystWidget_;

    //! error widget
    ErrorWidget* yErrorSystWidget_;

};

#endif
