// $Id: RefPointWidget.cpp,v 1.24 2014/02/03 10:08:24 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "IconSize.h"

#include "RefPointWidget.h"
#include "RefPointWidget.moc"

#include "BaseIconNames.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "LineEditor.h"
#include "QuestionDialog.h"
#include "RefPointDialog.h"

//________________________________________________________________________
RefPointWidget::RefPointWidget( QWidget* parent ):
    QObject( parent ),
    Counter( "RefPointWidget" ),
    initialized_( false ),
    hovered_( false ),
    selected_( false )
{
    Debug::Throw( "RefPointWidget::RefPointWidget.\n" );

    // name
    nameLabel_ = new QLabel( parent );
    nameLabel_->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    nameLabel_->setAttribute( Qt::WA_Hover, true );

    // global point
    globalPointLabel_ = new QLabel( parent );
    globalPointLabel_->setAlignment( Qt::AlignCenter );
    globalPointLabel_->setAttribute( Qt::WA_Hover, true );

    // local point
    localPointLabel_ = new QLabel( parent );
    localPointLabel_->setAlignment( Qt::AlignCenter );
    localPointLabel_->setAttribute( Qt::WA_Hover, true );

    // edit action
    parent->addAction( editAction_ = new QAction( IconEngine::get( IconNames::Edit ), tr( "Edit" ), parent ) );
    editAction_->setToolTip( tr( "Edit reference point's local coordinates" ) );
    editAction_->setEnabled( false );

    // edit action
    parent->addAction( clearAction_ = new QAction( IconEngine::get( IconNames::Remove ), tr( "Remove" ), parent ) );
    clearAction_->setToolTip( tr( "Erase reference point" ) );
    clearAction_->setEnabled( false );

    // toolbar
    toolbar_ = new CustomToolBar( tr( "Referecence Point" ), parent );
    toolbar_->setTransparent( true );
    toolbar_->setMovable( false );
    toolbar_->setToolButtonStyle(Qt::ToolButtonIconOnly );
    toolbar_->setIconSize( IconSize( IconSize::Small ) );
    toolbar_->addAction( editAction_ );
    toolbar_->addAction( clearAction_ );

}

//________________________________________________________________________
void RefPointWidget::clear( void )
{
    Debug::Throw( "RefPointWidget::clear.\n" );
    point_.clear();
    globalPointLabel().clear();
    localPointLabel().clear();
    setSelected( false );

    // update actions
    editAction_->setEnabled( false );
    clearAction_->setEnabled( false );
    emit modified();
}

//________________________________________________________________________
void RefPointWidget::setPoint( const RefPoint& refPoint )
{

    Debug::Throw( "RefPointWidget::setPoint.\n" );

    // check for differences
    const bool changed( point_.local() != refPoint.local() || point_.global() != refPoint.global() );

    // assign
    point_ = refPoint;

    // global point
    globalPointLabel_->setText( point_.global().toString() + " " );
    localPointLabel_->setText( point_.local().toString() + " " );

    // update actions
    editAction_->setEnabled( true );
    clearAction_->setEnabled( true );

    if( changed ) emit modified();

}

//________________________________________________________________________
bool RefPointWidget::setHovered( bool value )
{

    Debug::Throw() << "RefPointWidget::setHovered - " << value << endl;
    if( hovered_ == value ) return false;
    hovered_ = value;
    return true;
}

//________________________________________________________________________
bool RefPointWidget::setSelected( bool value )
{
    Debug::Throw() << "RefPointWidget::setSelected - " << value << endl;

    if( selected_ == value ) return false;
    selected_ = value;

    if( selected_ )
    {

        nameLabel().setForegroundRole( QPalette::HighlightedText );
        globalPointLabel().setForegroundRole( QPalette::HighlightedText );
        localPointLabel().setForegroundRole( QPalette::HighlightedText );

    } else {

        nameLabel().setForegroundRole( QPalette::WindowText );
        globalPointLabel().setForegroundRole( QPalette::WindowText );
        localPointLabel().setForegroundRole( QPalette::WindowText );

    }

    return true;

}
